# String Obfuscator

## Description
This module provides easy, out-of-the-box obfuscation solution for Python dicts.
It provides simple obfuscation algorithm to hide important information contained inside simple or nested dictionaries.
Works by replacing strings '*'.
This module obfuscates strings, integers, list items.

## How to use
This module was developed with easy-of-use in mind, so it's pretty straightforward:

Step-by-step guide:
+ `from string_obfuscator.obfuscate import obfuscate`
+ Dict can be obfuscated by calling: `obfuscate(dict_to_obfuscate, list_with_keys_to_obfuscate)`
+ Enum can also be passed as an optional parameter: `obfuscate(dict_to_obfuscate, [], enum_with_keys_to_obfuscate)`

## Python version
This module was tested in Python 3.7, 3.8.5, 3.9